@@ -26,7 +26,7 @@
 ##SOFTWARE.
 ##
 
-import sys, getopt, os, os.path, cv2, filetype
+import sys, getopt, os, os.path, cv2, re, filetype
 from .text_gen import generate_ascii_t
 from .image_gen import generate_ascii_i
 from .video_gen import generate_ascii_v
@@ -41,6 +41,10 @@ def main(argv):
    inputfile = ''
    outputfile = ''
    cam_source = ''
+   hex_code = '^(?:[0-9a-fA-F]{3}){1,2}$'
+   colors = ['black','blue','green','cyan','red','magenta','yellow','white']
+   fcolor = (255,255,255)
+   bcolor = (0,0,0)
    no_device=False
    fancy = False #default
 
@@ -59,17 +63,24 @@ def main(argv):
       # ofile - output image or video file
       # cam_source - camera source for webcam mode
       # fancy - fancy mode
-      opts, args = getopt.getopt(argv,"hm:c:k:d:i:o:s:f",["help","color=","mode=","kernel=","density=","ifile=","ofile=","cam_source=","fancy"])
+      # fcolor, bcolor - front and background colors for binary color mode (to be used only in case of binary mode)
+      opts, args = getopt.getopt(argv,"hm:c:k:d:i:o:s:f",["help","color=","fcolor=","bcolor=","mode=","kernel=","density=","ifile=","ofile=","cam_source=","fancy"])
    except getopt.GetoptError:
       print('For text   : img2ascii.py -m <mode>[t=text] -i <inputfile> -o <outputfile> -k <kernel_size>[optional] -d <text_density>[optional]')
-      print('For image  : img2ascii.py -m <mode>[i=image] -c[color mode (optional)] -i <inputfile> -o <outputfile> -k <kernel_size>[optional] -d <text_density>[optional] -f [fancy mode (optional)]')
-      print('For video  : img2ascii.py -m <mode>[v=video] -c[color mode (optional)] -i <inputfile> -o <outputfile> -k <kernel_size>[optional] -d <text_density>[optional]  -f [fancy mode (optional)]')
-      print('For webcam : img2ascii.py -m <mode>[w=webcam] -c[color mode (optional)] -k <kernel_size>[optional] -d <text_density>[optional] -s <source_camera (0,1,2...)>[optional]  -f [fancy mode (optional)]')
+      print('For image  : img2ascii.py -m <mode>[i=image] -c[color mode (optional)] --fcolor <text_color_hex>[optional] --bcolor <background_color_hex>[optional] -i <inputfile> -o <outputfile> -k <kernel_size>[optional] -d <text_density>[optional] -f [fancy mode (optional)]')
+      print('For video  : img2ascii.py -m <mode>[v=video] -c[color mode (optional)] --fcolor <text_color_hex>[optional] --bcolor <background_color_hex>[optional] -i <inputfile> -o <outputfile> -k <kernel_size>[optional] -d <text_density>[optional]  -f [fancy mode (optional)]')
+      print('For webcam : img2ascii.py -m <mode>[w=webcam] -c[color mode (optional)] --fcolor <text_color_hex>[optional] --bcolor <background_color_hex>[optional] -k <kernel_size>[optional] -d <text_density>[optional] -s <source_camera (0,1,2...)>[optional]  -f [fancy mode (optional)]')
       print('To get help on usage : img2ascii.py -h <or> img2ascii.py --help')
       sys.exit(2)
+   
    for opt, arg in opts:
 
       if opt == '-h':
+         print('')
+         print('img2ascii')
+         print('')
+         print('Authors:')
+         print(' Gopalji Gaur <gopaljigaur@gmail.com>')
          print('')
          print('img2ascii is a library written in python which can convert image or video files to ASCII')
          print('')
@@ -77,7 +88,11 @@ def main(argv):
          print('')
          print('-h or --help       : To generate this help text')
          print('-m or --mode       : Select the mode of operation -- `t` for text, `i` for image, `v` for video and `w` for webcam input')
-         print('-c or --color      : Optional parameter to select color mode. 0 - B/W, 1 - Grayscale and 2 - RGB. Default color mode is B/W')
+         print('-c or --color      : Optional parameter to select color mode. 0 - binary, 1 - Grayscale and 2 - RGB. Default color mode is binary')
+         print('--fcolor           : Optional parameter to set the text color in binary color mode. Default = white')
+         print('--bcolor           : Optional parameter to set the background color in binary color mode. Default = black')
+         print('                     for --fcolor and --bcolor, you can use color names - [white, black, red, green, blue, yellow, cyan, magenta]')
+         print('                     For all other colors hex color codes must be supplied')
          print('-k or --kernel     : Optional parameter to set the kernel size, default is 7px')
          print('-d or --density    : Optional parameter to set the ASCII text density on image, default is 0.3 units; Range - (0,1) (exclusive)')
          print('-i or --ifile      : Path to the input file for image and video modes')
@@ -104,10 +119,40 @@ def main(argv):
       elif opt in ("-c", "--color"):
          color = int(arg)
          if not color in (0,1,2):
-            print('Please select one of the following color modes : 0 - B/W, 1 - Grayscale and 2 - RGB')
+            print('Please select one of the following color modes : 0 - binary, 1 - Grayscale and 2 - RGB')
             print('To get help on usage : img2ascii.py -h <or> img2ascii.py --help')
             sys.exit()
 
+      elif opt in ("--fcolor"):
+         fcolor = arg
+         if fcolor in colors:
+            fcolor = "{0:b}".format(colors.index(fcolor))
+            while(len(fcolor)<3):
+               fcolor="0"+fcolor
+            fcolor = list(fcolor)
+            fcolor = tuple(int(i)*255 for i in fcolor)
+            
+         elif(re.match(hex_code,fcolor)):
+            fcolor = (int(fcolor[0:2],16),int(fcolor[2:4],16),int(fcolor[4:6],16))
+         else:
+            print('Please give a valid value for fcolor')
+            sys.exit()
+
+      elif opt in ("--bcolor"):
+         bcolor = arg
+         if bcolor in colors:
+            bcolor = "{0:b}".format(colors.index(bcolor))
+            while(len(bcolor)<3):
+               bcolor="0"+bcolor
+            bcolor=list(bcolor)
+            bcolor = tuple(int(i)*255 for i in bcolor)
+            
+         elif(re.match(hex_code,bcolor)):
+            bcolor = (int(bcolor[0:2],16),int(bcolor[2:4],16),int(bcolor[4:6],16))
+         else:
+            print('Please give a valid value for bcolor')
+            sys.exit()
+            
       elif opt in ("-k", "--kernel"):
          kernel = arg
          if not kernel.isnumeric() or kernel=='0':
@@ -193,7 +238,7 @@ def main(argv):
       print('|     Parameters     |')
       print(' -------------------- ')
       if(color==0):
-         print('Selected color mode : B/W')
+         print('Selected color mode : binary')
       elif(color==1):
          print('Selected color mode : Grayscale')
       elif(color==2):
@@ -202,8 +247,11 @@ def main(argv):
       print('Text density : ',density)
       print('Input file   : ', inputfile)
       print('Output file  : ', outputfile)
+      if(color==0):
+         print('Text color       : ',fcolor)
+         print('Background color : ',bcolor)
       print('')
-      generate_ascii_i(inputfile,outputfile,color,kernel,density,fancy)
+      generate_ascii_i(inputfile,outputfile,color,kernel,density,fancy,fcolor,bcolor)
 
    elif(mode=='v'):
       print('//////////////////////')
@@ -217,7 +265,7 @@ def main(argv):
       print('|     Parameters     |')
       print(' -------------------- ')
       if(color==0):
-         print('Selected color mode : B/W')
+         print('Selected color mode : binary')
       elif(color==1):
          print('Selected color mode : Grayscale')
       elif(color==2):
@@ -226,8 +274,11 @@ def main(argv):
       print('Text density : ',density)
       print('Input file   : ', inputfile)
       print('Output file  : ', outputfile)
+      if(color==0):
+         print('Text color       : ',fcolor)
+         print('Background color : ',bcolor)
       print('')
-      generate_ascii_v(inputfile,outputfile,color,kernel,density,fancy)
+      generate_ascii_v(inputfile,outputfile,color,kernel,density,fancy,fcolor,bcolor)
 
    elif(mode=='w'):
       if(no_device):
@@ -268,7 +319,7 @@ def main(argv):
       print('|     Parameters     |')
       print(' -------------------- ')
       if(color==0):
-         print('Selected color mode : B/W')
+         print('Selected color mode : binary')
       elif(color==1):
          print('Selected color mode : Grayscale')
       elif(color==2):
@@ -276,8 +327,11 @@ def main(argv):
       print('Kernel size  : ',kernel)
       print('Text density : ',density)
       print('Video source : ',device_list.get(cam_source))
+      if(color==0):
+         print('Text color       : ',fcolor)
+         print('Background color : ',bcolor)
       print('')
-      generate_ascii_w(color,kernel,density,cam_source,device_list.get(cam_source),fancy)
+      generate_ascii_w(color,kernel,density,cam_source,device_list.get(cam_source),fancy,fcolor,bcolor)
 
 def getCamera():
    graph = FilterGraph()
